@@ -1,6 +1,6 @@
 /*
  hole.c -- convert huge files with mostly NULs to/from source_hole
- Copyright (C) 2014-2017 Dieter Baron and Thomas Klausner
+ Copyright (C) 2014-2018 Dieter Baron and Thomas Klausner
 
  This file is part of libzip, a library to manipulate ZIP archives.
  The authors can be contacted at <libzip@nih.at>
@@ -51,7 +51,7 @@
 
 zip_source_t *source_hole_create(const char *, int flags, zip_error_t *);
 
-const char *prg;
+const char *progname;
 
 
 static int
@@ -60,19 +60,19 @@ copy_source(zip_source_t *from, zip_source_t *to) {
     zip_int64_t n;
 
     if (zip_source_open(from) < 0) {
-	fprintf(stderr, "%s: can't open source for reading: %s\n", prg, zip_error_strerror(zip_source_error(from)));
+	fprintf(stderr, "%s: can't open source for reading: %s\n", progname, zip_error_strerror(zip_source_error(from)));
 	return -1;
     }
 
     if (zip_source_begin_write(to) < 0) {
-	fprintf(stderr, "%s: can't open source for writing: %s\n", prg, zip_error_strerror(zip_source_error(to)));
+	fprintf(stderr, "%s: can't open source for writing: %s\n", progname, zip_error_strerror(zip_source_error(to)));
 	zip_source_close(from);
 	return -1;
     }
 
     while ((n = zip_source_read(from, buf, sizeof(buf))) > 0) {
 	if (zip_source_write(to, buf, (zip_uint64_t)n) != n) {
-	    fprintf(stderr, "%s: can't write to source: %s\n", prg, zip_error_strerror(zip_source_error(to)));
+	    fprintf(stderr, "%s: can't write to source: %s\n", progname, zip_error_strerror(zip_source_error(to)));
 	    zip_source_close(from);
 	    zip_source_rollback_write(to);
 	    return -1;
@@ -80,7 +80,7 @@ copy_source(zip_source_t *from, zip_source_t *to) {
     }
 
     if (n < 0) {
-	fprintf(stderr, "%s: can't read from source: %s\n", prg, zip_error_strerror(zip_source_error(from)));
+	fprintf(stderr, "%s: can't read from source: %s\n", progname, zip_error_strerror(zip_source_error(from)));
 	zip_source_close(from);
 	zip_source_rollback_write(to);
 	return -1;
@@ -89,7 +89,7 @@ copy_source(zip_source_t *from, zip_source_t *to) {
     zip_source_close(from);
 
     if (zip_source_commit_write(to) < 0) {
-	fprintf(stderr, "%s: can't commit source: %s\n", prg, zip_error_strerror(zip_source_error(to)));
+	fprintf(stderr, "%s: can't commit source: %s\n", progname, zip_error_strerror(zip_source_error(to)));
 	zip_source_rollback_write(to);
 	return -1;
     }
@@ -106,7 +106,7 @@ open_compressed(const char *fname, int flags) {
     zip_error_init(&error);
 
     if ((src = source_hole_create(fname, flags, &error)) == NULL) {
-	fprintf(stderr, "%s: can't open compressed file %s: %s\n", prg, fname, zip_error_strerror(&error));
+	fprintf(stderr, "%s: can't open compressed file %s: %s\n", progname, fname, zip_error_strerror(&error));
 	zip_error_fini(&error);
 	exit(1);
     }
@@ -123,7 +123,7 @@ open_file(const char *fname) {
     zip_error_init(&error);
 
     if ((src = zip_source_file_create(fname, 0, 0, &error)) == NULL) {
-	fprintf(stderr, "%s: can't open file %s: %s\n", prg, fname, zip_error_strerror(&error));
+	fprintf(stderr, "%s: can't open file %s: %s\n", progname, fname, zip_error_strerror(&error));
 	zip_error_fini(&error);
 	exit(1);
     }
@@ -134,7 +134,7 @@ open_file(const char *fname) {
 
 static void
 usage(void) {
-    fprintf(stderr, "usage: %s [-du] in out\n", prg);
+    fprintf(stderr, "usage: %s [-du] in out\n", progname);
     fprintf(stderr, "\nOptions:\n  -d  decompress in\n  -u  update in\n");
     exit(1);
 }
@@ -148,7 +148,7 @@ main(int argc, char **argv) {
     int compress = 1;
     int decompress = 0;
 
-    prg = argv[0];
+    progname = argv[0];
 
     while ((c = getopt(argc, argv, "du")) != -1) {
 	switch (c) {
